from distutils.core import setup

setup(
    name='blackleg',
    version='1.0.0',
    packages=['blackleg'],
    url='https://github.com/blackleg/python-commons',
    license='Apache',
    author='blackleg',
    author_email='hectorespertpardo@gmail.com',
    description='Blackleg python packages'
)
